@@ -10,11 +10,11 @@ pub(crate) struct ReadDirInner {
 impl ReadDirInner {
     pub(crate) fn new(start: &fs::File, path: &Path) -> io::Result<Self> {
         let dir = open_dir(start, path)?;
-        Self::new_unchecked(&dir, Component::CurDir.as_os_str().as_ref())
+        Self::new_unchecked(&dir, Component::CurDir.as_ref())
     }
 
     pub(crate) fn read_base_dir(start: &fs::File) -> io::Result<Self> {
-        Self::new_unchecked(&start, Component::CurDir.as_os_str().as_ref())
+        Self::new_unchecked(&start, Component::CurDir.as_ref())
     }
 
     pub(crate) fn new_unchecked(start: &fs::File, path: &Path) -> io::Result<Self> {
